Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(128)

Unified Diff: base/trace_event/memory_tracing_observer.cc

Issue 2865243003: memory-infra: Rename Enable/Disable in MemoryDumpManager. (Closed)
Patch Set: rebase Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « base/trace_event/memory_dump_manager_unittest.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: base/trace_event/memory_tracing_observer.cc
diff --git a/base/trace_event/memory_tracing_observer.cc b/base/trace_event/memory_tracing_observer.cc
index 8847b8045cf35c7261376bb54afb7cc067b9a342..2208cedf40f8d04d92adaccc8c6eae0b0664338f 100644
--- a/base/trace_event/memory_tracing_observer.cc
+++ b/base/trace_event/memory_tracing_observer.cc
@@ -49,7 +49,8 @@ void MemoryTracingObserver::OnTraceLogEnabled() {
return;
// Initialize the TraceLog for the current thread. This is to avoids that the
// TraceLog memory dump provider is registered lazily during the MDM Enable()
TraceLog::GetInstance()->InitializeThreadLocalEventBufferIfSupported();
const TraceConfig& trace_config =
@@ -60,11 +61,11 @@ void MemoryTracingObserver::OnTraceLogEnabled() {
memory_dump_config_ =
MakeUnique<TraceConfig::MemoryDumpConfig>(memory_dump_config);
- memory_dump_manager_->Enable(memory_dump_config);
+ memory_dump_manager_->SetupForTracing(memory_dump_config);
}
void MemoryTracingObserver::OnTraceLogDisabled() {
- memory_dump_manager_->Disable();
+ memory_dump_manager_->TeardownForTracing();
memory_dump_config_.reset();
}
« no previous file with comments | « base/trace_event/memory_dump_manager_unittest.cc ('k') | no next file » | no next file with comments »
@@ -49,7 +49,8 @@ void MemoryTracingObserver::OnTraceLogEnabled() {
return;
// Initialize the TraceLog for the current thread. This is to avoids that the
- // TraceLog memory dump provider is registered lazily during the MDM Enable()
+ // TraceLog memory dump provider is registered lazily during the MDM
+ // SetupForTracing().
TraceLog::GetInstance()->InitializeThreadLocalEventBufferIfSupported();
const TraceConfig& trace_config =

Powered by Google App Engine
This is Rietveld 408576698